@@ -8,6 +8,8 @@ from warnings import warn
 from requests.exceptions import RetryError
 from requests_toolbelt.multipart.encoder import MultipartEncoder
 
+from sdcclient.secure.scanning import ScanningAlertsClientV1
+
 try:
     from urllib.parse import quote_plus, unquote_plus
 except ImportError:
@@ -16,8 +18,7 @@ except ImportError:
 from sdcclient._common import _SdcCommon
 
 
-class SdScanningClient(_SdcCommon):
-
+class SdScanningClient(ScanningAlertsClientV1, _SdcCommon):
     def __init__(self, token="", sdc_url='https://secure.sysdig.com', ssl_verify=True, custom_headers=None):
         super(SdScanningClient, self).__init__(token, sdc_url, ssl_verify, custom_headers)
         self.product = "SDS"
@@ -47,9 +48,9 @@ class SdScanningClient(_SdcCommon):
             payload['annotations'] = annotations
 
         url = "{base_url}/api/scanning/v1/anchore/images?autosubscribe={autosubscribe}{force}".format(
-            base_url=self.url,
-            autosubscribe=str(autosubscribe),
-            force="&force=true" if force else "")
+                base_url=self.url,
+                autosubscribe=str(autosubscribe),
+                force="&force=true" if force else "")
 
         res = self.http.post(url, data=json.dumps(payload), headers=self.hdrs, verify=self.ssl_verify)
         if not self._checkResponse(res):
@@ -78,8 +79,8 @@ class SdScanningClient(_SdcCommon):
 
         url = self.url + "/api/scanning/v1/anchore/images"
         url += {
-            'imageid': '/by_id/{}'.format(image),
-            'imageDigest': '/{}'.format(image)
+                'imageid':     '/by_id/{}'.format(image),
+                'imageDigest': '/{}'.format(image)
         }.get(itype, '')
 
         res = self.http.get(url, params=params, headers=self.hdrs, verify=self.ssl_verify)
@@ -209,12 +210,12 @@ class SdScanningClient(_SdcCommon):
             A JSON object representing the images.
         '''
         url = "{base_url}/api/scanning/v1/anchore/query/images/by_vulnerability?vulnerability_id={vulnerability_id}{namespace}{package}{severity}&vendor_only={vendor_only}".format(
-            base_url=self.url,
-            vulnerability_id=vulnerability_id,
-            namespace="&namespace={}".format(namespace) if namespace else "",
-            package="&affected_package={}".format(package) if package else "",
-            severity="&severity={}".format(severity) if severity else "",
-            vendor_only=vendor_only)
+                base_url=self.url,
+                vulnerability_id=vulnerability_id,
+                namespace="&namespace={}".format(namespace) if namespace else "",
+                package="&affected_package={}".format(package) if package else "",
+                severity="&severity={}".format(severity) if severity else "",
+                vendor_only=vendor_only)
 
         res = self.http.get(url, headers=self.hdrs, verify=self.ssl_verify)
         if not self._checkResponse(res):
@@ -235,10 +236,10 @@ class SdScanningClient(_SdcCommon):
             A JSON object representing the images.
         '''
         url = "{base_url}/api/scanning/v1/anchore/query/images/by_package?name={name}{version}{package_type}".format(
-            base_url=self.url,
-            name=name,
-            version="&version={}".format(version) if version else "",
-            package_type="&package_type={}".format(package_type) if package_type else "")
+                base_url=self.url,
+                name=name,
+                version="&version={}".format(version) if version else "",
+                package_type="&package_type={}".format(package_type) if package_type else "")
 
         res = self.http.get(url, headers=self.hdrs, verify=self.ssl_verify)
         if not self._checkResponse(res):
@@ -255,11 +256,11 @@ class SdScanningClient(_SdcCommon):
             return [False, "cannot use input image string (no discovered imageDigest)"]
 
         url = "{base_url}/api/scanning/v1/anchore/images/{image_digest}/{query_group}/{query_type}{vendor_only}".format(
-            base_url=self.url,
-            image_digest=image_digest,
-            query_group=query_group,
-            query_type=query_type if query_type else '',
-            vendor_only="?vendor_only={}".format(vendor_only) if query_group == 'vuln' else '')
+                base_url=self.url,
+                image_digest=image_digest,
+                query_group=query_group,
+                query_type=query_type if query_type else '',
+                vendor_only="?vendor_only={}".format(vendor_only) if query_group == 'vuln' else '')
 
         res = self.http.get(url, headers=self.hdrs, verify=self.ssl_verify)
         if not self._checkResponse(res):
@@ -309,12 +310,12 @@ class SdScanningClient(_SdcCommon):
 
         url = "{base_url}/api/scanning/v1/anchore/images/{image_digest}/check?history={history}&detail={detail}&tag={tag}{policy_id}"
         url = url.format(
-            base_url=self.url,
-            image_digest=image_digest,
-            history=str(show_history).lower(),
-            detail=str(detail).lower(),
-            tag=thetag,
-            policy_id=("&policyId=%s" % policy) if policy else "")
+                base_url=self.url,
+                image_digest=image_digest,
+                history=str(show_history).lower(),
+                detail=str(detail).lower(),
+                tag=thetag,
+                policy_id=("&policyId=%s" % policy) if policy else "")
 
         res = self.http.get(url, headers=self.hdrs, verify=self.ssl_verify)
         if not self._checkResponse(res):
@@ -343,10 +344,10 @@ class SdScanningClient(_SdcCommon):
         image_tag = tag if tag else image
 
         url = "{base_url}/api/scanning/v1/images/{image_digest}/report?tag={tag}{at}".format(
-            base_url=self.url,
-            image_digest=image_digest,
-            tag=image_tag,
-            at=("&at=%s" % date) if date else "")
+                base_url=self.url,
+                image_digest=image_digest,
+                tag=image_tag,
+                at=("&at=%s" % date) if date else "")
 
         res = self.http.get(url, headers=self.hdrs, verify=self.ssl_verify)
         if not self._checkResponse(res):
@@ -366,9 +367,9 @@ class SdScanningClient(_SdcCommon):
             The pdf content
         '''
         url = "{base_url}/api/scanning/v1/images/{image_digest}/report?tag={tag}".format(
-            base_url=self.url,
-            image_digest=image_digest,
-            tag=full_tag)
+                base_url=self.url,
+                image_digest=image_digest,
+                tag=full_tag)
 
         res = self.http.get(url, headers=self.hdrs, verify=self.ssl_verify)
         if not self._checkResponse(res):
@@ -390,7 +391,7 @@ class SdScanningClient(_SdcCommon):
         '''
         try:
             m = MultipartEncoder(
-                fields={'archive_file': (infile, open(infile, 'rb'), 'text/plain')}
+                    fields={'archive_file': (infile, open(infile, 'rb'), 'text/plain')}
             )
             if sync:
                 url = self.url + "/api/scanning/v1/anchore/import/images"
@@ -398,7 +399,7 @@ class SdScanningClient(_SdcCommon):
                 url = self.url + "/api/scanning/v1/import/images"
 
             headers = {'Authorization': 'Bearer ' + self.token, 'Content-Type': m.content_type,
-                       'imageId': image_id, 'digestId': digest_id, 'imageName': image_name}
+                       'imageId':       image_id, 'digestId': digest_id, 'imageName': image_name}
             res = self.http.post(url, data=m, headers=headers, verify=self.ssl_verify)
             if not self._checkResponse(res):
                 return [False, self.lasterr]
@@ -438,10 +439,10 @@ class SdScanningClient(_SdcCommon):
             A JSON object containing pass/fail status of image scan policy.
         '''
         url = "{base_url}/api/scanning/v1/anchore/images/by_id/{image_id}/check?tag={full_tag_name}&detail={detail}".format(
-            base_url=self.url,
-            image_id=image_id,
-            full_tag_name=full_tag_name,
-            detail=detail)
+                base_url=self.url,
+                image_id=image_id,
+                full_tag_name=full_tag_name,
+                detail=detail)
         res = self.http.get(url, headers=self.hdrs, verify=self.ssl_verify)
         if not self._checkResponse(res):
             return [False, self.lasterr]
@@ -475,14 +476,14 @@ class SdScanningClient(_SdcCommon):
             registry_type = self._get_registry_type(registry)
 
         payload = {
-            'registry': registry,
-            'registry_user': registry_user,
-            'registry_pass': registry_pass,
-            'registry_type': registry_type,
-            'registry_verify': not insecure}
+                'registry':        registry,
+                'registry_user':   registry_user,
+                'registry_pass':   registry_pass,
+                'registry_type':   registry_type,
+                'registry_verify': not insecure}
         url = "{base_url}/api/scanning/v1/anchore/registries?validate={validate}".format(
-            base_url=self.url,
-            validate=validate)
+                base_url=self.url,
+                validate=validate)
 
         res = self.http.post(url, data=json.dumps(payload), headers=self.hdrs, verify=self.ssl_verify)
         if not self._checkResponse(res):
@@ -511,15 +512,15 @@ class SdScanningClient(_SdcCommon):
                     "input registry name cannot contain '/' characters - valid registry names are of the form <host>:<port> where :<port> is optional"]
 
         payload = {
-            'registry': registry,
-            'registry_user': registry_user,
-            'registry_pass': registry_pass,
-            'registry_type': registry_type,
-            'registry_verify': not insecure}
+                'registry':        registry,
+                'registry_user':   registry_user,
+                'registry_pass':   registry_pass,
+                'registry_type':   registry_type,
+                'registry_verify': not insecure}
         url = "{base_url}/api/scanning/v1/anchore/registries/{registry}?validate={validate}".format(
-            base_url=self.url,
-            registry=registry,
-            validate=validate)
+                base_url=self.url,
+                registry=registry,
+                validate=validate)
 
         res = self.http.put(url, data=json.dumps(payload), headers=self.hdrs, verify=self.ssl_verify)
         if not self._checkResponse(res):
@@ -605,10 +606,10 @@ class SdScanningClient(_SdcCommon):
             A JSON object representing the repo.
         '''
         url = "{base_url}/api/scanning/v1/anchore/repositories?repository={repo}&autosubscribe={autosubscribe}{lookuptag}".format(
-            base_url=self.url,
-            repo=repo,
-            autosubscribe=autosubscribe,
-            lookuptag="&lookuptag={}".format(lookuptag) if lookuptag else "")
+                base_url=self.url,
+                repo=repo,
+                autosubscribe=autosubscribe,
+                lookuptag="&lookuptag={}".format(lookuptag) if lookuptag else "")
 
         res = self.http.post(url, headers=self.hdrs, verify=self.ssl_verify)
         if not self._checkResponse(res):
@@ -681,10 +682,10 @@ class SdScanningClient(_SdcCommon):
             A JSON object containing the policy description.
         '''
         policy = {
-            'name': name,
-            'comment': comment,
-            'rules': rules,
-            'version': '1_0'
+                'name':    name,
+                'comment': comment,
+                'rules':   rules,
+                'version': '1_0'
         }
         if bundleid:
             policy['policyBundleId'] = bundleid
@@ -699,8 +700,8 @@ class SdScanningClient(_SdcCommon):
 
     def list_policy_bundles(self, detail=False):
         url = "{base_url}/api/scanning/v1/anchore/policies?detail={detail}".format(
-            base_url=self.url,
-            detail=str(detail))
+                base_url=self.url,
+                detail=str(detail))
         res = self.http.get(url, headers=self.hdrs, verify=self.ssl_verify)
         if not self._checkResponse(res):
             return [False, self.lasterr]
@@ -787,28 +788,35 @@ class SdScanningClient(_SdcCommon):
 
     def add_alert(self, name, description=None, scope="", triggers={'failed': True, 'unscanned': True},
                   enabled=False, notification_channels=[]):
-        '''**Description**
-            Create a new alert
-
-        **Arguments**
-            - name: The name of the alert.
-            - description: The descprition of the alert.
-            - scope: An AND-composed string of predicates that selects the scope in which the alert will be applied. (like: 'host.domain = "example.com" and container.image != "alpine:latest"')
-            - tiggers: A dict {str: bool} indicating wich triggers should be enabled/disabled. (default: {'failed': True, 'unscanned': True})
-            - enabled: Whether this alert should actually be applied.
-            - notification_channels: A list of notification channel ids.
-
-        **Success Return Value**
-            A JSON object containing the alert description.
         '''
+        Create a new alert
+        **Warning**: `add_alert` is deprecated and will be removed soon, use
+        `add_runtime_alert` or `add_repository_alert` from `ScanningAlertsClientV1` instead.
+
+        Args:
+            name(str): The name of the alert.
+            description(str): The descprition of the alert.
+            scope(str): An AND-composed string of predicates that selects the scope in which the alert will be applied. (like: 'host.domain = "example.com" and container.image != "alpine:latest"')
+            tiggers(dict): A dict {str: bool} indicating wich triggers should be enabled/disabled. (default: {'failed': True, 'unscanned': True})
+            enabled(bool): Whether this alert should actually be applied.
+            notification_channels(list): A list of notification channel ids.
+
+        Returns:
+            A JSON object containing the alert description.
+
+        .. deprecated::
+            `add_alert` is deprecated and will be removed soon, use
+            `add_runtime_alert` or `add_repository_alert` from `ScanningAlertsClientV1` instead.
+        '''
+
         alert = {
-            'name': name,
-            'description': description,
-            'triggers': triggers,
-            'scope': scope,
-            'enabled': enabled,
-            'autoscan': True,
-            'notificationChannelIds': notification_channels,
+                'name':                   name,
+                'description':            description,
+                'triggers':               triggers,
+                'scope':                  scope,
+                'enabled':                enabled,
+                'autoscan':               True,
+                'notificationChannelIds': notification_channels,
         }
 
         url = self.url + '/api/scanning/v1/alerts'
@@ -819,56 +827,22 @@ class SdScanningClient(_SdcCommon):
 
         return [True, res.json()]
 
-    def list_alerts(self, limit=None, cursor=None):
-        '''**Description**
-            List the current set of scanning alerts.
-
-        **Arguments**
-            - limit: Maximum number of alerts in the response.
-            - cursor: An opaque string representing the current position in the list of alerts. It's provided in the 'responseMetadata' of the list_alerts response.
-
-        **Success Return Value**
-            A JSON object containing the list of alerts.
-        '''
-        url = self.url + '/api/scanning/v1/alerts'
-        if limit:
-            url += '?limit=' + str(limit)
-            if cursor:
-                url += '&cursor=' + cursor
-
-        res = self.http.get(url, headers=self.hdrs, verify=self.ssl_verify)
-        if not self._checkResponse(res):
-            return [False, self.lasterr]
-
-        return [True, res.json()]
-
-    def get_alert(self, alertid):
-        '''**Description**
-            Retrieve the scanning alert with the given id
-
-        **Arguments**
-            - alertid: Unique identifier associated with this alert.
-
-        **Success Return Value**
-            A JSON object containing the alert description.
-        '''
-        url = self.url + '/api/scanning/v1/alerts/' + alertid
-        res = self.http.get(url, headers=self.hdrs, verify=self.ssl_verify)
-        if not self._checkResponse(res):
-            return [False, self.lasterr]
-
-        return [True, res.json()]
-
     def update_alert(self, alertid, alert_description):
-        '''**Description**
-            Update the alert with the given id
+        '''
+        Update the alert with the given id.
+        **Warning**: `update_alert` is deprecated and will be removed soon, use
+        `update_runtime_alert` or `update_repository_alert` from `ScanningAlertsClientV1` instead.
 
-        **Arguments**
-            - alertid: Unique identifier associated with this alert.
-            - alert_description: A dictionary with the alert description.
+        Args:
+            alertid(str): Unique identifier associated with this alert.
+            alert_description(str): A dictionary with the alert description.
 
-        **Success Return Value**
+        Returns:
             A JSON object containing the alert description.
+
+        .. deprecated::
+            `update_alert` is deprecated and will be removed soon, use
+            `update_runtime_alert` or `update_repository_alert` from `ScanningAlertsClientV1` instead.
         '''
         url = self.url + '/api/scanning/v1/alerts/' + alertid
         data = json.dumps(alert_description)
@@ -878,20 +852,6 @@ class SdScanningClient(_SdcCommon):
 
         return [True, res.json()]
 
-    def delete_alert(self, policyid):
-        '''**Description**
-            Delete the alert with the given id
-
-        **Arguments**
-            - alertid: Unique identifier associated with this alert.
-        '''
-        url = self.url + '/api/scanning/v1/alerts/' + policyid
-        res = self.http.delete(url, headers=self.hdrs, verify=self.ssl_verify)
-        if not self._checkResponse(res):
-            return [False, self.lasterr]
-
-        return [True, res.text]
-
     def get_subscriptions(self, subscription_type=None, subscription_key=None):
         '''**Description**
             Get the list of subscriptions
@@ -1020,8 +980,8 @@ class SdScanningClient(_SdcCommon):
             A JSON object representing the list of runtime containers.
         '''
         containers = {
-            'scope': scope,
-            'skipPolicyEvaluation': skip_policy_evaluation
+                'scope':                scope,
+                'skipPolicyEvaluation': skip_policy_evaluation
         }
         if start_time or end_time:
             containers['time'] = {}
@@ -1084,7 +1044,7 @@ class SdScanningClient(_SdcCommon):
         url = f"{self.url}/api/scanning/v1/anchore/query/vulnerabilities"
 
         params = {
-            "id": id,
+                "id": id,
         }
 
         res = self.http.get(url, params=params, headers=self.hdrs, verify=self.ssl_verify)
@@ -1103,9 +1063,9 @@ class SdScanningClient(_SdcCommon):
 
         url = f"{self.url}/api/scanning/v1/vulnexceptions"
         params = {
-            "version": "1_0",
-            "name": name,
-            "comment": comment,
+                "version": "1_0",
+                "name":    name,
+                "comment": comment,
         }
 
         data = json.dumps(params)
@@ -1129,7 +1089,7 @@ class SdScanningClient(_SdcCommon):
         url = f"{self.url}/api/scanning/v1/vulnexceptions"
 
         params = {
-            "bundleId": "default",
+                "bundleId": "default",
         }
 
         res = self.http.get(url, params=params, headers=self.hdrs, verify=self.ssl_verify)
@@ -1142,7 +1102,7 @@ class SdScanningClient(_SdcCommon):
         url = f"{self.url}/api/scanning/v1/vulnexceptions/{bundle}"
 
         params = {
-            "bundleId": "default",
+                "bundleId": "default",
         }
 
         res = self.http.get(url, params=params, headers=self.hdrs, verify=self.ssl_verify)
@@ -1158,11 +1118,11 @@ class SdScanningClient(_SdcCommon):
         url = f"{self.url}/api/scanning/v1/vulnexceptions/{bundle}/vulnerabilities"
 
         params = {
-            "gate": "vulnerabilities",
-            "is_busy": False,
-            "trigger_id": f"{cve}+*",
-            "expiration_date": int(expiration_date) if expiration_date else None,
-            "notes": note,
+                "gate":            "vulnerabilities",
+                "is_busy":         False,
+                "trigger_id":      f"{cve}+*",
+                "expiration_date": int(expiration_date) if expiration_date else None,
+                "notes":           note,
         }
 
         data = json.dumps(params)
@@ -1178,7 +1138,7 @@ class SdScanningClient(_SdcCommon):
         url = f"{self.url}/api/scanning/v1/vulnexceptions/{bundle}/vulnerabilities/{id}"
 
         params = {
-            "bundleId": "default",
+                "bundleId": "default",
         }
 
         res = self.http.delete(url, params=params, headers=self.hdrs, verify=self.ssl_verify)
@@ -1191,15 +1151,15 @@ class SdScanningClient(_SdcCommon):
         url = f"{self.url}/api/scanning/v1/vulnexceptions/{bundle}/vulnerabilities/{id}"
 
         data = {
-            "id": id,
-            "gate": "vulnerabilities",
-            "trigger_id": f"{cve}+*",
-            "enabled": enabled,
-            "notes": note,
-            "expiration_date": int(expiration_date) if expiration_date else None,
+                "id":              id,
+                "gate":            "vulnerabilities",
+                "trigger_id":      f"{cve}+*",
+                "enabled":         enabled,
+                "notes":           note,
+                "expiration_date": int(expiration_date) if expiration_date else None,
         }
         params = {
-            "bundleId": "default",
+                "bundleId": "default",
         }
 
         res = self.http.put(url, data=json.dumps(data), params=params, headers=self.hdrs, verify=self.ssl_verify)
@@ -1227,18 +1187,17 @@ class SdScanningClient(_SdcCommon):
         url = f"{self.url}/api/scanning/v1/reports/csv"
 
         params = {
-            "queryType": "vuln",
-            "scopeType": scope_type,
-            "staticScope":
-                {
-                    "registry": "",
-                    "repository": "",
-                    "tag": ""
+                "queryType":        "vuln",
+                "scopeType":        scope_type,
+                "staticScope":      {
+                        "registry":   "",
+                        "repository": "",
+                        "tag":        ""
                 },
-            "runtimeScope": {},
-            "imageQueryFilter": {"vType": vuln_type},
-            "offset": 0,
-            "limit": 100000
+                "runtimeScope":     {},
+                "imageQueryFilter": {"vType": vuln_type},
+                "offset":           0,
+                "limit":            100000
         }
 
         res = self.http.post(url, data=json.dumps(params), headers=self.hdrs, verify=self.ssl_verify)
@@ -1272,7 +1231,7 @@ class SdScanningClient(_SdcCommon):
 
         url = f"{self.url}/api/scanning/v1/images/{image_digest}/policyEvaluation"
         params = {
-            "tag": image_tag,
+                "tag": image_tag,
         }
 
         res = self.http.get(url, headers=self.hdrs, params=params, verify=self.ssl_verify)
@@ -1282,17 +1241,17 @@ class SdScanningClient(_SdcCommon):
         json_res = res.json()
 
         result = {
-            "image_digest": json_res["imageDigest"],
-            "image_id": json_res["imageId"],
-            "status": json_res["status"],
-            "image_tag": image_tag,
-            "total_stop": json_res["nStop"],
-            "total_warn": json_res["nWarn"],
-            "last_evaluation": datetime.utcfromtimestamp(json_res["at"]),
-            "policy_id": "*",
-            "policy_name": "All policies",
-            "warn_results": [],
-            "stop_results": []
+                "image_digest":    json_res["imageDigest"],
+                "image_id":        json_res["imageId"],
+                "status":          json_res["status"],
+                "image_tag":       image_tag,
+                "total_stop":      json_res["nStop"],
+                "total_warn":      json_res["nWarn"],
+                "last_evaluation": datetime.utcfromtimestamp(json_res["at"]),
+                "policy_id":       "*",
+                "policy_name":     "All policies",
+                "warn_results":    [],
+                "stop_results":    []
         }
 
         if policy_id:
